@@ -2,7 +2,7 @@ use 5.006;
 
 package WWW::Scripter;
 
-our $VERSION = '0.031';
+our $VERSION = '0.032';
 
 use strict; use warnings; no warnings qw 'utf8 parenthesis bareword';
 
@@ -267,11 +267,23 @@ sub request {
   }
 }
 
-# Protect against tied $_
-sub get { return SUPER::get{@_} for my $foo }
-sub put { return SUPER::put{@_} for my $foo }
-sub post { return SUPER::post{@_} for my $foo }
-sub head { return SUPER::head{@_} for my $foo }
+for my $method (qw < get put post head >){
+ no strict 'refs';
+ *$method = sub {
+   for(my $foo) { # protect against tied $_
+     my ($self, $uri) = (shift, shift);
+     $uri = $uri->url if ref $uri eq 'WWW::Mechanize::Link';
+     my $abs = new_abs URI $uri, my $base = $self->base;
+     # URI screws up data fragments
+     if ($abs =~ /^data:#/i && $abs ne $uri && $uri =~ /^#/) {
+         $abs = "$base$uri";
+     }
+     # For get and put, we have replicated here what the Mech methods do,
+     # so for speed’s sake go straight to LWP.
+     return $self->${\"LWP::UserAgent::$method"}($abs, @_);
+   }
+ };
+}
 
 
 # The only difference between this one and Mech is the args to
@@ -424,7 +436,9 @@ sub update_html {
 
 			        $code = decode $cs||$elem->charset
 			            ||$tree->charset||'latin1',
-			          $res->decoded_content(charset=>'none');
+			          $res->decoded_content(
+			            charset=>'none', raise_error=>1
+			          );
 			        
 			        
 			        $line = 1;
